# Table of Contents

- [configuring-sap-btp-cloud-foundry-integration](<./configuring-sap-btp-cloud-foundry-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP BTP, Cloud Foundry Integration for SAP Discovery](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery.md>)
  - [Overview](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Overview.md>)
  - [Prerequisites](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Prerequisites.md>)
  - [Step 1: Create a Platform User in Your IAS Tenant](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Step-1-Create-a-Platform-User-in-Your-IAS-Tenant.md>)
  - [Step 2: Create an SAP Cloud Management Service Instance and Service Key](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Step-2-Create-an-SAP-Cloud-Management-Service-Instance-and-Service-Key.md>)
  - [Step 3: Add the Platform User to SAP BTP, Cloud Foundry Organizations and Spaces](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Step-3-Add-the-Platform-User-to-SAP-BTP-Cloud-Foundry-Organizations-and-Spaces.md>)
  - [Step 4: Connect SAP LeanIX to SAP BTP, Cloud Foundry](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Step-4-Connect-SAP-LeanIX-to-SAP-BTP-Cloud-Foundry.md>)
  - [Linking Discovered Items to Fact Sheets](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Linking-Discovered-Items-to-Fact-Sheets.md>)
  - [Viewing Synchronization Logs](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/Viewing-Synchronization-Logs.md>)
  - [SAP BTP Meta Model Extension](<./SAP-BTP-Cloud-Foundry-Integration-for-SAP-Discovery/SAP-BTP-Meta-Model-Extension.md>)
